@@ -11,11 +11,11 @@ import (
 	"github.com/smallstep/cli/crypto/randutil"
 	"github.com/smallstep/cli/flags"
 	"github.com/smallstep/cli/jose"
-	"github.com/smallstep/cli/ui"
 	"github.com/smallstep/cli/utils"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/command"
 	"go.step.sm/cli-utils/errs"
+	"go.step.sm/cli-utils/ui"
 )
 
 const (
