@@ -14,12 +14,12 @@ import (
 	"github.com/smallstep/certificates/templates"
 	"github.com/smallstep/cli/crypto/sshutil"
 	"github.com/smallstep/cli/flags"
-	"github.com/smallstep/cli/ui"
 	"github.com/smallstep/cli/utils/cautils"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/command"
 	"go.step.sm/cli-utils/errs"
 	"go.step.sm/cli-utils/step"
+	"go.step.sm/cli-utils/ui"
 	"golang.org/x/crypto/ssh"
 )
 
